# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRCALC_METADATA = Metadata(
    id="4abff4f051d8a436c35f7a012c41ca90bb2f4df0.boutiques",
    name="mrcalc",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class MrcalcAbs:
    """
    |%1| : return absolute value (magnitude) of real or complex number.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-abs")
        return cargs


@dataclasses.dataclass
class MrcalcNeg:
    """
    -%1 : negative value.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-neg")
        return cargs


@dataclasses.dataclass
class MrcalcAdd:
    """
    (%1 + %2) : add values.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-add")
        return cargs


@dataclasses.dataclass
class MrcalcSubtract:
    """
    (%1 - %2) : subtract nth operand from (n-1)th.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-subtract")
        return cargs


@dataclasses.dataclass
class MrcalcMultiply:
    """
    (%1 * %2) : multiply values.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-multiply")
        return cargs


@dataclasses.dataclass
class MrcalcDivide:
    """
    (%1 / %2) : divide (n-1)th operand by nth.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-divide")
        return cargs


@dataclasses.dataclass
class MrcalcMin:
    """
    min (%1, %2) : smallest of last two operands.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-min")
        return cargs


@dataclasses.dataclass
class MrcalcMax:
    """
    max (%1, %2) : greatest of last two operands.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-max")
        return cargs


@dataclasses.dataclass
class MrcalcLt:
    """
    (%1 < %2) : less-than operator (true=1, false=0).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-lt")
        return cargs


@dataclasses.dataclass
class MrcalcGt:
    """
    (%1 > %2) : greater-than operator (true=1, false=0).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-gt")
        return cargs


@dataclasses.dataclass
class MrcalcLe:
    """
    (%1 <= %2) : less-than-or-equal-to operator (true=1, false=0).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-le")
        return cargs


@dataclasses.dataclass
class MrcalcGe:
    """
    (%1 >= %2) : greater-than-or-equal-to operator (true=1, false=0).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-ge")
        return cargs


@dataclasses.dataclass
class MrcalcEq:
    """
    (%1 == %2) : equal-to operator (true=1, false=0).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-eq")
        return cargs


@dataclasses.dataclass
class MrcalcNeq:
    """
    (%1 != %2) : not-equal-to operator (true=1, false=0).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-neq")
        return cargs


@dataclasses.dataclass
class MrcalcIf:
    """
    (%1 ? %2 : %3) : if first operand is true (non-zero), return second operand,
    otherwise return third operand.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-if")
        return cargs


@dataclasses.dataclass
class MrcalcReplace:
    """
    (%1, %2 -> %3) : Wherever first operand is equal to the second operand,
    replace with third operand.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-replace")
        return cargs


@dataclasses.dataclass
class MrcalcSqrt:
    """
    sqrt (%1) : square root.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-sqrt")
        return cargs


@dataclasses.dataclass
class MrcalcPow:
    """
    %1^%2 : raise (n-1)th operand to nth power.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-pow")
        return cargs


@dataclasses.dataclass
class MrcalcRound:
    """
    round (%1) : round to nearest integer.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-round")
        return cargs


@dataclasses.dataclass
class MrcalcCeil:
    """
    ceil (%1) : round up to nearest integer.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-ceil")
        return cargs


@dataclasses.dataclass
class MrcalcFloor:
    """
    floor (%1) : round down to nearest integer.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-floor")
        return cargs


@dataclasses.dataclass
class MrcalcNot:
    """
    !%1 : NOT operator: true (1) if operand is false (i.e. zero).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-not")
        return cargs


@dataclasses.dataclass
class MrcalcAnd:
    """
    (%1 && %2) : AND operator: true (1) if both operands are true (i.e.
    non-zero).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-and")
        return cargs


@dataclasses.dataclass
class MrcalcOr:
    """
    (%1 || %2) : OR operator: true (1) if either operand is true (i.e.
    non-zero).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-or")
        return cargs


@dataclasses.dataclass
class MrcalcXor:
    """
    (%1 ^^ %2) : XOR operator: true (1) if only one of the operands is true
    (i.e. non-zero).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-xor")
        return cargs


@dataclasses.dataclass
class MrcalcIsnan:
    """
    isnan (%1) : true (1) if operand is not-a-number (NaN).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-isnan")
        return cargs


@dataclasses.dataclass
class MrcalcIsinf:
    """
    isinf (%1) : true (1) if operand is infinite (Inf).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-isinf")
        return cargs


@dataclasses.dataclass
class MrcalcFinite:
    """
    finite (%1) : true (1) if operand is finite (i.e. not NaN or Inf).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-finite")
        return cargs


@dataclasses.dataclass
class MrcalcComplex:
    """
    (%1 + %2 i) : create complex number using the last two operands as
    real,imaginary components.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-complex")
        return cargs


@dataclasses.dataclass
class MrcalcPolar:
    """
    (%1 /_ %2) : create complex number using the last two operands as
    magnitude,phase components (phase in radians).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-polar")
        return cargs


@dataclasses.dataclass
class MrcalcReal:
    """
    real (%1) : real part of complex number.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-real")
        return cargs


@dataclasses.dataclass
class MrcalcImag:
    """
    imag (%1) : imaginary part of complex number.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-imag")
        return cargs


@dataclasses.dataclass
class MrcalcPhase:
    """
    phase (%1) : phase of complex number (use -abs for magnitude).
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-phase")
        return cargs


@dataclasses.dataclass
class MrcalcConj:
    """
    conj (%1) : complex conjugate.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-conj")
        return cargs


@dataclasses.dataclass
class MrcalcProj:
    """
    proj (%1) : projection onto the Riemann sphere.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-proj")
        return cargs


@dataclasses.dataclass
class MrcalcExp:
    """
    exp (%1) : exponential function.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-exp")
        return cargs


@dataclasses.dataclass
class MrcalcLog:
    """
    log (%1) : natural logarithm.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-log")
        return cargs


@dataclasses.dataclass
class MrcalcLog10:
    """
    log10 (%1) : common logarithm.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-log10")
        return cargs


@dataclasses.dataclass
class MrcalcCos:
    """
    cos (%1) : cosine.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cos")
        return cargs


@dataclasses.dataclass
class MrcalcSin:
    """
    sin (%1) : sine.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-sin")
        return cargs


@dataclasses.dataclass
class MrcalcTan:
    """
    tan (%1) : tangent.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-tan")
        return cargs


@dataclasses.dataclass
class MrcalcAcos:
    """
    acos (%1) : inverse cosine.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-acos")
        return cargs


@dataclasses.dataclass
class MrcalcAsin:
    """
    asin (%1) : inverse sine.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-asin")
        return cargs


@dataclasses.dataclass
class MrcalcAtan:
    """
    atan (%1) : inverse tangent.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-atan")
        return cargs


@dataclasses.dataclass
class MrcalcCosh:
    """
    cosh (%1) : hyperbolic cosine.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cosh")
        return cargs


@dataclasses.dataclass
class MrcalcSinh:
    """
    sinh (%1) : hyperbolic sine.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-sinh")
        return cargs


@dataclasses.dataclass
class MrcalcTanh:
    """
    tanh (%1) : hyperbolic tangent.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-tanh")
        return cargs


@dataclasses.dataclass
class MrcalcAcosh:
    """
    acosh (%1) : inverse hyperbolic cosine.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-acosh")
        return cargs


@dataclasses.dataclass
class MrcalcAsinh:
    """
    asinh (%1) : inverse hyperbolic sine.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-asinh")
        return cargs


@dataclasses.dataclass
class MrcalcAtanh:
    """
    atanh (%1) : inverse hyperbolic tangent.
    """
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-atanh")
        return cargs


@dataclasses.dataclass
class MrcalcConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


@dataclasses.dataclass
class MrcalcVariousString:
    obj: str
    """String object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(self.obj)
        return cargs


@dataclasses.dataclass
class MrcalcVariousFile:
    obj: InputPathType
    """File object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.obj))
        return cargs


class MrcalcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mrcalc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mrcalc(
    operand: list[typing.Union[MrcalcVariousString, MrcalcVariousFile]],
    abs_: list[MrcalcAbs] | None = None,
    neg: list[MrcalcNeg] | None = None,
    add: list[MrcalcAdd] | None = None,
    subtract: list[MrcalcSubtract] | None = None,
    multiply: list[MrcalcMultiply] | None = None,
    divide: list[MrcalcDivide] | None = None,
    min_: list[MrcalcMin] | None = None,
    max_: list[MrcalcMax] | None = None,
    lt: list[MrcalcLt] | None = None,
    gt: list[MrcalcGt] | None = None,
    le: list[MrcalcLe] | None = None,
    ge: list[MrcalcGe] | None = None,
    eq: list[MrcalcEq] | None = None,
    neq: list[MrcalcNeq] | None = None,
    if_: list[MrcalcIf] | None = None,
    replace: list[MrcalcReplace] | None = None,
    sqrt: list[MrcalcSqrt] | None = None,
    pow_: list[MrcalcPow] | None = None,
    round_: list[MrcalcRound] | None = None,
    ceil: list[MrcalcCeil] | None = None,
    floor: list[MrcalcFloor] | None = None,
    not_: list[MrcalcNot] | None = None,
    and_: list[MrcalcAnd] | None = None,
    or_: list[MrcalcOr] | None = None,
    xor: list[MrcalcXor] | None = None,
    isnan: list[MrcalcIsnan] | None = None,
    isinf: list[MrcalcIsinf] | None = None,
    finite: list[MrcalcFinite] | None = None,
    complex_: list[MrcalcComplex] | None = None,
    polar: list[MrcalcPolar] | None = None,
    real: list[MrcalcReal] | None = None,
    imag: list[MrcalcImag] | None = None,
    phase: list[MrcalcPhase] | None = None,
    conj: list[MrcalcConj] | None = None,
    proj: list[MrcalcProj] | None = None,
    exp: list[MrcalcExp] | None = None,
    log: list[MrcalcLog] | None = None,
    log10: list[MrcalcLog10] | None = None,
    cos: list[MrcalcCos] | None = None,
    sin: list[MrcalcSin] | None = None,
    tan: list[MrcalcTan] | None = None,
    acos: list[MrcalcAcos] | None = None,
    asin: list[MrcalcAsin] | None = None,
    atan: list[MrcalcAtan] | None = None,
    cosh: list[MrcalcCosh] | None = None,
    sinh: list[MrcalcSinh] | None = None,
    tanh: list[MrcalcTanh] | None = None,
    acosh: list[MrcalcAcosh] | None = None,
    asinh: list[MrcalcAsinh] | None = None,
    atanh: list[MrcalcAtanh] | None = None,
    datatype: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[MrcalcConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MrcalcOutputs:
    """
    Apply generic voxel-wise mathematical operations to images.
    
    This command will only compute per-voxel operations. Use 'mrmath' to compute
    summary statistics across images or along image axes.
    
    This command uses a stack-based syntax, with operators (specified using
    options) operating on the top-most entries (i.e. images or values) in the
    stack. Operands (values or images) are pushed onto the stack in the order
    they appear (as arguments) on the command-line, and operators (specified as
    options) operate on and consume the top-most entries in the stack, and push
    their output as a new entry on the stack.
    
    As an additional feature, this command will allow images with different
    dimensions to be processed, provided they satisfy the following conditions:
    for each axis, the dimensions match if they are the same size, or one of
    them has size one. In the latter case, the entire image will be replicated
    along that axis. This allows for example a 4D image of size [ X Y Z N ] to
    be added to a 3D image of size [ X Y Z ], as if it consisted of N copies of
    the 3D image along the 4th axis (the missing dimension is assumed to have
    size 1). Another example would a single-voxel 4D image of size [ 1 1 1 N ],
    multiplied by a 3D image of size [ X Y Z ], which would allow the creation
    of a 4D image where each volume consists of the 3D image scaled by the
    corresponding value for that volume in the single-voxel image.
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        operand: an input image, intensity value, or the special keywords\
            'rand' (random number between 0 and 1) or 'randn' (random number from\
            unit std.dev. normal distribution) or the mathematical constants 'e'\
            and 'pi'.
        abs_: |%1| : return absolute value (magnitude) of real or complex\
            number.
        neg: -%1 : negative value.
        add: (%1 + %2) : add values.
        subtract: (%1 - %2) : subtract nth operand from (n-1)th.
        multiply: (%1 * %2) : multiply values.
        divide: (%1 / %2) : divide (n-1)th operand by nth.
        min_: min (%1, %2) : smallest of last two operands.
        max_: max (%1, %2) : greatest of last two operands.
        lt: (%1 < %2) : less-than operator (true=1, false=0).
        gt: (%1 > %2) : greater-than operator (true=1, false=0).
        le: (%1 <= %2) : less-than-or-equal-to operator (true=1, false=0).
        ge: (%1 >= %2) : greater-than-or-equal-to operator (true=1, false=0).
        eq: (%1 == %2) : equal-to operator (true=1, false=0).
        neq: (%1 != %2) : not-equal-to operator (true=1, false=0).
        if_: (%1 ? %2 : %3) : if first operand is true (non-zero), return\
            second operand, otherwise return third operand.
        replace: (%1, %2 -> %3) : Wherever first operand is equal to the second\
            operand, replace with third operand.
        sqrt: sqrt (%1) : square root.
        pow_: %1^%2 : raise (n-1)th operand to nth power.
        round_: round (%1) : round to nearest integer.
        ceil: ceil (%1) : round up to nearest integer.
        floor: floor (%1) : round down to nearest integer.
        not_: !%1 : NOT operator: true (1) if operand is false (i.e. zero).
        and_: (%1 && %2) : AND operator: true (1) if both operands are true\
            (i.e. non-zero).
        or_: (%1 || %2) : OR operator: true (1) if either operand is true (i.e.\
            non-zero).
        xor: (%1 ^^ %2) : XOR operator: true (1) if only one of the operands is\
            true (i.e. non-zero).
        isnan: isnan (%1) : true (1) if operand is not-a-number (NaN).
        isinf: isinf (%1) : true (1) if operand is infinite (Inf).
        finite: finite (%1) : true (1) if operand is finite (i.e. not NaN or\
            Inf).
        complex_: (%1 + %2 i) : create complex number using the last two\
            operands as real,imaginary components.
        polar: (%1 /_ %2) : create complex number using the last two operands\
            as magnitude,phase components (phase in radians).
        real: real (%1) : real part of complex number.
        imag: imag (%1) : imaginary part of complex number.
        phase: phase (%1) : phase of complex number (use -abs for magnitude).
        conj: conj (%1) : complex conjugate.
        proj: proj (%1) : projection onto the Riemann sphere.
        exp: exp (%1) : exponential function.
        log: log (%1) : natural logarithm.
        log10: log10 (%1) : common logarithm.
        cos: cos (%1) : cosine.
        sin: sin (%1) : sine.
        tan: tan (%1) : tangent.
        acos: acos (%1) : inverse cosine.
        asin: asin (%1) : inverse sine.
        atan: atan (%1) : inverse tangent.
        cosh: cosh (%1) : hyperbolic cosine.
        sinh: sinh (%1) : hyperbolic sine.
        tanh: tanh (%1) : hyperbolic tangent.
        acosh: acosh (%1) : inverse hyperbolic cosine.
        asinh: asinh (%1) : inverse hyperbolic sine.
        atanh: atanh (%1) : inverse hyperbolic tangent.
        datatype: specify output image data type. Valid choices are: float32,\
            float32le, float32be, float64, float64le, float64be, int64, uint64,\
            int64le, uint64le, int64be, uint64be, int32, uint32, int32le, uint32le,\
            int32be, uint32be, int16, uint16, int16le, uint16le, int16be, uint16be,\
            cfloat32, cfloat32le, cfloat32be, cfloat64, cfloat64le, cfloat64be,\
            int8, uint8, bit.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrcalcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRCALC_METADATA)
    cargs = []
    cargs.append("mrcalc")
    if abs_ is not None:
        cargs.extend([a for c in [s.run(execution) for s in abs_] for a in c])
    if neg is not None:
        cargs.extend([a for c in [s.run(execution) for s in neg] for a in c])
    if add is not None:
        cargs.extend([a for c in [s.run(execution) for s in add] for a in c])
    if subtract is not None:
        cargs.extend([a for c in [s.run(execution) for s in subtract] for a in c])
    if multiply is not None:
        cargs.extend([a for c in [s.run(execution) for s in multiply] for a in c])
    if divide is not None:
        cargs.extend([a for c in [s.run(execution) for s in divide] for a in c])
    if min_ is not None:
        cargs.extend([a for c in [s.run(execution) for s in min_] for a in c])
    if max_ is not None:
        cargs.extend([a for c in [s.run(execution) for s in max_] for a in c])
    if lt is not None:
        cargs.extend([a for c in [s.run(execution) for s in lt] for a in c])
    if gt is not None:
        cargs.extend([a for c in [s.run(execution) for s in gt] for a in c])
    if le is not None:
        cargs.extend([a for c in [s.run(execution) for s in le] for a in c])
    if ge is not None:
        cargs.extend([a for c in [s.run(execution) for s in ge] for a in c])
    if eq is not None:
        cargs.extend([a for c in [s.run(execution) for s in eq] for a in c])
    if neq is not None:
        cargs.extend([a for c in [s.run(execution) for s in neq] for a in c])
    if if_ is not None:
        cargs.extend([a for c in [s.run(execution) for s in if_] for a in c])
    if replace is not None:
        cargs.extend([a for c in [s.run(execution) for s in replace] for a in c])
    if sqrt is not None:
        cargs.extend([a for c in [s.run(execution) for s in sqrt] for a in c])
    if pow_ is not None:
        cargs.extend([a for c in [s.run(execution) for s in pow_] for a in c])
    if round_ is not None:
        cargs.extend([a for c in [s.run(execution) for s in round_] for a in c])
    if ceil is not None:
        cargs.extend([a for c in [s.run(execution) for s in ceil] for a in c])
    if floor is not None:
        cargs.extend([a for c in [s.run(execution) for s in floor] for a in c])
    if not_ is not None:
        cargs.extend([a for c in [s.run(execution) for s in not_] for a in c])
    if and_ is not None:
        cargs.extend([a for c in [s.run(execution) for s in and_] for a in c])
    if or_ is not None:
        cargs.extend([a for c in [s.run(execution) for s in or_] for a in c])
    if xor is not None:
        cargs.extend([a for c in [s.run(execution) for s in xor] for a in c])
    if isnan is not None:
        cargs.extend([a for c in [s.run(execution) for s in isnan] for a in c])
    if isinf is not None:
        cargs.extend([a for c in [s.run(execution) for s in isinf] for a in c])
    if finite is not None:
        cargs.extend([a for c in [s.run(execution) for s in finite] for a in c])
    if complex_ is not None:
        cargs.extend([a for c in [s.run(execution) for s in complex_] for a in c])
    if polar is not None:
        cargs.extend([a for c in [s.run(execution) for s in polar] for a in c])
    if real is not None:
        cargs.extend([a for c in [s.run(execution) for s in real] for a in c])
    if imag is not None:
        cargs.extend([a for c in [s.run(execution) for s in imag] for a in c])
    if phase is not None:
        cargs.extend([a for c in [s.run(execution) for s in phase] for a in c])
    if conj is not None:
        cargs.extend([a for c in [s.run(execution) for s in conj] for a in c])
    if proj is not None:
        cargs.extend([a for c in [s.run(execution) for s in proj] for a in c])
    if exp is not None:
        cargs.extend([a for c in [s.run(execution) for s in exp] for a in c])
    if log is not None:
        cargs.extend([a for c in [s.run(execution) for s in log] for a in c])
    if log10 is not None:
        cargs.extend([a for c in [s.run(execution) for s in log10] for a in c])
    if cos is not None:
        cargs.extend([a for c in [s.run(execution) for s in cos] for a in c])
    if sin is not None:
        cargs.extend([a for c in [s.run(execution) for s in sin] for a in c])
    if tan is not None:
        cargs.extend([a for c in [s.run(execution) for s in tan] for a in c])
    if acos is not None:
        cargs.extend([a for c in [s.run(execution) for s in acos] for a in c])
    if asin is not None:
        cargs.extend([a for c in [s.run(execution) for s in asin] for a in c])
    if atan is not None:
        cargs.extend([a for c in [s.run(execution) for s in atan] for a in c])
    if cosh is not None:
        cargs.extend([a for c in [s.run(execution) for s in cosh] for a in c])
    if sinh is not None:
        cargs.extend([a for c in [s.run(execution) for s in sinh] for a in c])
    if tanh is not None:
        cargs.extend([a for c in [s.run(execution) for s in tanh] for a in c])
    if acosh is not None:
        cargs.extend([a for c in [s.run(execution) for s in acosh] for a in c])
    if asinh is not None:
        cargs.extend([a for c in [s.run(execution) for s in asinh] for a in c])
    if atanh is not None:
        cargs.extend([a for c in [s.run(execution) for s in atanh] for a in c])
    if datatype is not None:
        cargs.extend([
            "-datatype",
            datatype
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.extend([a for c in [s.run(execution) for s in operand] for a in c])
    ret = MrcalcOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRCALC_METADATA",
    "MrcalcAbs",
    "MrcalcAcos",
    "MrcalcAcosh",
    "MrcalcAdd",
    "MrcalcAnd",
    "MrcalcAsin",
    "MrcalcAsinh",
    "MrcalcAtan",
    "MrcalcAtanh",
    "MrcalcCeil",
    "MrcalcComplex",
    "MrcalcConfig",
    "MrcalcConj",
    "MrcalcCos",
    "MrcalcCosh",
    "MrcalcDivide",
    "MrcalcEq",
    "MrcalcExp",
    "MrcalcFinite",
    "MrcalcFloor",
    "MrcalcGe",
    "MrcalcGt",
    "MrcalcIf",
    "MrcalcImag",
    "MrcalcIsinf",
    "MrcalcIsnan",
    "MrcalcLe",
    "MrcalcLog",
    "MrcalcLog10",
    "MrcalcLt",
    "MrcalcMax",
    "MrcalcMin",
    "MrcalcMultiply",
    "MrcalcNeg",
    "MrcalcNeq",
    "MrcalcNot",
    "MrcalcOr",
    "MrcalcOutputs",
    "MrcalcPhase",
    "MrcalcPolar",
    "MrcalcPow",
    "MrcalcProj",
    "MrcalcReal",
    "MrcalcReplace",
    "MrcalcRound",
    "MrcalcSin",
    "MrcalcSinh",
    "MrcalcSqrt",
    "MrcalcSubtract",
    "MrcalcTan",
    "MrcalcTanh",
    "MrcalcVariousFile",
    "MrcalcVariousString",
    "MrcalcXor",
    "mrcalc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL_ERODE_METADATA = Metadata(
    id="d61ae2acb345083e76990bfa8a4104ae10b7c74b.boutiques",
    name="label-erode",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class LabelErodeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label_erode(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """the output label file"""


def label_erode(
    label: InputPathType,
    surface: InputPathType,
    erode_dist: float,
    label_out: str,
    opt_roi_roi_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> LabelErodeOutputs:
    """
    Erode a label file.
    
    Around each vertex that is unlabeled, set surrounding vertices to unlabeled.
    The surrounding vertices are all immediate neighbors and all vertices within
    the specified distance.
    
    Note that the -corrected-areas option uses an approximate correction for
    distance along the surface.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label: the input label.
        surface: the surface to erode on.
        erode_dist: distance in mm to erode the labels.
        label_out: the output label file.
        opt_roi_roi_metric: assume values outside this roi are labeled: metric\
            file, positive values denote vertices that have data.
        opt_column_column: select a single column to erode: the column number\
            or name.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelErodeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_ERODE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-erode")
    cargs.append(execution.input_file(label))
    cargs.append(execution.input_file(surface))
    cargs.append(str(erode_dist))
    cargs.append(label_out)
    if opt_roi_roi_metric is not None:
        cargs.extend([
            "-roi",
            execution.input_file(opt_roi_roi_metric)
        ])
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    if opt_corrected_areas_area_metric is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(opt_corrected_areas_area_metric)
        ])
    ret = LabelErodeOutputs(
        root=execution.output_file("."),
        label_out=execution.output_file(label_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL_ERODE_METADATA",
    "LabelErodeOutputs",
    "label_erode",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AVW2FSL_METADATA = Metadata(
    id="4bd3a4636820978ce77e10fce31f85d6ab419486.boutiques",
    name="avw2fsl",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class Avw2fslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `avw2fsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dest: OutputPathType
    """Destination file or directory where the source is copied."""


def avw2fsl(
    source: list[str],
    destination: str,
    archive: bool = False,
    attributes_only: bool = False,
    backup: str | None = None,
    backup_noarg: bool = False,
    copy_contents: bool = False,
    no_dereference_preserve_links: bool = False,
    force: bool = False,
    interactive: bool = False,
    follow_symlinks_cmdline: bool = False,
    hard_link: bool = False,
    dereference: bool = False,
    no_clobber: bool = False,
    no_dereference: bool = False,
    preserve: bool = False,
    preserve_attr: str | None = None,
    preserve_context: bool = False,
    no_preserve: str | None = None,
    parents: bool = False,
    recursive: bool = False,
    reflink: str | None = None,
    remove_destination: bool = False,
    sparse: str | None = None,
    strip_trailing_slashes: bool = False,
    symbolic_link: bool = False,
    suffix: str | None = None,
    target_directory: str | None = None,
    no_target_directory: bool = False,
    update_: bool = False,
    verbose: bool = False,
    one_file_system: bool = False,
    selinux_context: bool = False,
    context: str | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Avw2fslOutputs:
    """
    Processing script to copy files and directories.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        source: Source file(s) or directory to copy.
        destination: Destination file or directory where the source is to be\
            copied.
        archive: Archive mode; same as -dR --preserve=all.
        attributes_only: Don't copy the file data, just the attributes.
        backup: Make a backup of each existing destination file.
        backup_noarg: Like --backup but does not accept an argument.
        copy_contents: Copy contents of special files when recursive.
        no_dereference_preserve_links: Same as --no-dereference\
            --preserve=links.
        force: If an existing destination file cannot be opened, remove it and\
            try again.
        interactive: Prompt before overwrite.
        follow_symlinks_cmdline: Follow command-line symbolic links in SOURCE.
        hard_link: Hard link files instead of copying.
        dereference: Always follow symbolic links in SOURCE.
        no_clobber: Do not overwrite an existing file.
        no_dereference: Never follow symbolic links in SOURCE.
        preserve: Preserve mode, ownership, and timestamps.
        preserve_attr: Preserve the specified attributes (default:\
            mode,ownership,timestamps).
        preserve_context: Deprecated, same as --preserve=context.
        no_preserve: Don't preserve the specified attributes.
        parents: Use full source file name under DIRECTORY.
        recursive: Copy directories recursively.
        reflink: Control clone/CoW copies.
        remove_destination: Remove each existing destination file before\
            attempting to open it.
        sparse: Control creation of sparse files.
        strip_trailing_slashes: Remove any trailing slashes from each SOURCE\
            argument.
        symbolic_link: Make symbolic links instead of copying.
        suffix: Override the usual backup suffix.
        target_directory: Specify the target directory.
        no_target_directory: Treat DEST as a normal file.
        update_: Copy only when the SOURCE file is newer than the destination\
            file or when the destination file is missing.
        verbose: Explain what is being done.
        one_file_system: Stay on this file system.
        selinux_context: Set SELinux security context of destination file to\
            default type.
        context: Like -Z, or if CTX is specified set the SELinux or SMACK\
            security context to CTX.
        help_: Display this help and exit.
        version: Output version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Avw2fslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AVW2FSL_METADATA)
    cargs = []
    cargs.append("avw2fsl")
    cargs.extend(source)
    cargs.append(destination)
    if archive:
        cargs.append("-a")
    if attributes_only:
        cargs.append("--attributes-only")
    if backup is not None:
        cargs.append("--backup=" + backup)
    if backup_noarg:
        cargs.append("-b")
    if copy_contents:
        cargs.append("--copy-contents")
    if no_dereference_preserve_links:
        cargs.append("-d")
    if force:
        cargs.append("-f")
    if interactive:
        cargs.append("-i")
    if follow_symlinks_cmdline:
        cargs.append("-H")
    if hard_link:
        cargs.append("-l")
    if dereference:
        cargs.append("-L")
    if no_clobber:
        cargs.append("-n")
    if no_dereference:
        cargs.append("-P")
    if preserve:
        cargs.append("-p")
    if preserve_attr is not None:
        cargs.append("--preserve=" + preserve_attr)
    if preserve_context:
        cargs.append("-c")
    if no_preserve is not None:
        cargs.append("--no-preserve=" + no_preserve)
    if parents:
        cargs.append("--parents")
    if recursive:
        cargs.append("-R")
    if reflink is not None:
        cargs.append("--reflink=" + reflink)
    if remove_destination:
        cargs.append("--remove-destination")
    if sparse is not None:
        cargs.append("--sparse=" + sparse)
    if strip_trailing_slashes:
        cargs.append("--strip-trailing-slashes")
    if symbolic_link:
        cargs.append("-s")
    if suffix is not None:
        cargs.append("-S=" + suffix)
    if target_directory is not None:
        cargs.append("-t=" + target_directory)
    if no_target_directory:
        cargs.append("-T")
    if update_:
        cargs.append("-u")
    if verbose:
        cargs.append("-v")
    if one_file_system:
        cargs.append("-x")
    if selinux_context:
        cargs.append("-Z")
    if context is not None:
        cargs.append("--context=" + context)
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = Avw2fslOutputs(
        root=execution.output_file("."),
        output_dest=execution.output_file(destination),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AVW2FSL_METADATA",
    "Avw2fslOutputs",
    "avw2fsl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SUPER_RESOLUTION_METADATA = Metadata(
    id="971ff863d798c743fcbcf153281a68f737955b2e.boutiques",
    name="SuperResolution",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class SuperResolutionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `super_resolution(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    super_resolved_image: OutputPathType
    """The output super-resolved image file."""


def super_resolution(
    image_dimension: int,
    output_image: InputPathType,
    domain_image: InputPathType,
    gradient_sigma: float,
    mesh_size: float,
    number_of_levels: int,
    input_image_files: list[InputPathType],
    runner: Runner | None = None,
) -> SuperResolutionOutputs:
    """
    The SuperResolution tool enhances the spatial resolution of input images. The
    'gradientSigma' parameter is used in calculating the gradient magnitude of the
    input images for weighting the voxel points during fitting. If a negative
    'gradient' sigma is specified then no weighting is used.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Specifies the dimensionality of the input images\
            (e.g., 2 for 2D images, 3 for 3D images).
        output_image: The file path for the output super-resolved image.
        domain_image: The domain image is used as the template space for the\
            alignment of input images.
        gradient_sigma: The sigma used for calculating the gradient magnitude\
            of input images. If negative, no weighting is applied.
        mesh_size: The size of the mesh used in fitting.
        number_of_levels: The number of resolution levels to process.
        input_image_files: List of paths to input images to be processed for\
            super resolution.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SuperResolutionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SUPER_RESOLUTION_METADATA)
    cargs = []
    cargs.append("SuperResolution")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(output_image))
    cargs.append(execution.input_file(domain_image))
    cargs.append(str(gradient_sigma))
    cargs.append(str(mesh_size))
    cargs.append(str(number_of_levels))
    cargs.extend([execution.input_file(f) for f in input_image_files])
    ret = SuperResolutionOutputs(
        root=execution.output_file("."),
        super_resolved_image=execution.output_file(pathlib.Path(output_image).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SUPER_RESOLUTION_METADATA",
    "SuperResolutionOutputs",
    "super_resolution",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRISP_WRITE_METADATA = Metadata(
    id="7b8fc1540fc76774d461ee491e6eccf087b42779.boutiques",
    name="mrisp_write",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrispWriteOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mrisp_write(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """A file containing a surface-worth of per-vertex values saved in spherical
    coordinates."""


def mrisp_write(
    input_surface: InputPathType,
    overlay_filename: InputPathType,
    output_name: str,
    subjects_dir: str | None = None,
    coords: str | None = None,
    average_curvature: float | None = None,
    correlation_matrix: InputPathType | None = None,
    scale_factor: float | None = None,
    normalize_curvature: bool = False,
    verbose_vertex: float | None = None,
    write_diagnostics: bool = False,
    runner: Runner | None = None,
) -> MrispWriteOutputs:
    """
    This tool converts a surface overlay on a sphere into spherical coordinates.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Full path to input surface.
        overlay_filename: Full path to the overlay to map.
        output_name: Output file name. Can be full path to a .tif or .mgz file.
        subjects_dir: Set SUBJECTS_DIR. Default: uses environment variable.
        coords: Treat overlay as a surface and write it into a 3 frame\
            parameterization.
        average_curvature: Average curvature patterns navgs times.
        correlation_matrix: Use the overlay to compute the correlation matrix\
            within the specified label.
        scale_factor: Scale factor to adjust resolution of the spherical map.
        normalize_curvature: Normalize curvature by variance.
        verbose_vertex: Invoke diagnostics for specified vertex number.
        write_diagnostics: Write some diagnostics.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrispWriteOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRISP_WRITE_METADATA)
    cargs = []
    cargs.append("mrisp_write")
    cargs.append(execution.input_file(input_surface))
    cargs.append(execution.input_file(overlay_filename))
    cargs.append(output_name)
    if subjects_dir is not None:
        cargs.extend([
            "-SDIR",
            subjects_dir
        ])
    if coords is not None:
        cargs.extend([
            "-coords",
            coords
        ])
    if average_curvature is not None:
        cargs.extend([
            "-A",
            str(average_curvature)
        ])
    if correlation_matrix is not None:
        cargs.extend([
            "-CORR",
            execution.input_file(correlation_matrix)
        ])
    if scale_factor is not None:
        cargs.extend([
            "-SCALE",
            str(scale_factor)
        ])
    if normalize_curvature:
        cargs.append("-N")
    if verbose_vertex is not None:
        cargs.extend([
            "-V",
            str(verbose_vertex)
        ])
    if write_diagnostics:
        cargs.append("-W")
    ret = MrispWriteOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRISP_WRITE_METADATA",
    "MrispWriteOutputs",
    "mrisp_write",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_STRIP_NONWHITE_METADATA = Metadata(
    id="85cd600947bfda4ae61eea101b99ad79680f009b.boutiques",
    name="mri_strip_nonwhite",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriStripNonwhiteOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_strip_nonwhite(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Processed output volume file"""


def mri_strip_nonwhite(
    input_volume: InputPathType,
    transform: InputPathType,
    template_volume: InputPathType,
    output_volume: str,
    runner: Runner | None = None,
) -> MriStripNonwhiteOutputs:
    """
    Tool for processing MRI images, transforming volumetric data using provided
    transformation and template files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input MRI volume file.
        transform: Transformation file to be applied to the input volume.
        template_volume: Template volume file used in conjunction with the\
            transform.
        output_volume: Name of the output volume file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriStripNonwhiteOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_STRIP_NONWHITE_METADATA)
    cargs = []
    cargs.append("mri_strip_nonwhite")
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(transform))
    cargs.append(execution.input_file(template_volume))
    cargs.append(output_volume)
    ret = MriStripNonwhiteOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_STRIP_NONWHITE_METADATA",
    "MriStripNonwhiteOutputs",
    "mri_strip_nonwhite",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_COMPARE_AFFINE_METADATA = Metadata(
    id="05a5d8e8f58b82dd3d94b8878f12307d386f682c.boutiques",
    name="3dCompareAffine",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dCompareAffineOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_compare_affine(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output file containing comparison results of affine transformations"""


def v_3d_compare_affine(
    mask: str | None = None,
    dset: InputPathType | None = None,
    affine: list[str] | None = None,
    runner: Runner | None = None,
) -> V3dCompareAffineOutputs:
    """
    Compares two (or more) affine spatial transformations on a dataset and outputs
    measurements of their differences in spatial displacements.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        mask: Dataset containing non-zero voxels used as the region over which\
            to compare the affine transformations.
        dset: Dataset to compute an automask from it and use that mask as the\
            spatial region for comparison.
        affine: Input an affine transformation (file or 'MATRIX'). Multiple\
            '-affine' options can be used to input multiple files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dCompareAffineOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_COMPARE_AFFINE_METADATA)
    cargs = []
    cargs.append("3dCompareAffine")
    if mask is not None:
        cargs.extend([
            "-mask",
            mask
        ])
    if dset is not None:
        cargs.extend([
            "-dset",
            execution.input_file(dset)
        ])
    if affine is not None:
        cargs.extend([
            "-affine",
            *affine
        ])
    ret = V3dCompareAffineOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file("[OUTPUT_PREFIX]_comparison.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dCompareAffineOutputs",
    "V_3D_COMPARE_AFFINE_METADATA",
    "v_3d_compare_affine",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TQUAL_METADATA = Metadata(
    id="a5953b420d22f8f6c2b20824e280582d44af991c.boutiques",
    name="3dTqual",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTqualOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tqual(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    time_series: OutputPathType
    """The 1D time series with the quality index for each sub-brick"""


def v_3d_tqual(
    dataset: InputPathType,
    spearman: bool = False,
    quadrant: bool = False,
    autoclip: bool = False,
    automask: bool = False,
    clip: float | None = None,
    mask: InputPathType | None = None,
    range_: bool = False,
    runner: Runner | None = None,
) -> V3dTqualOutputs:
    """
    Computes a quality index for each sub-brick in a 3D+time dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: Input 3D+time dataset.
        spearman: Quality index is 1 minus the Spearman (rank) correlation\
            coefficient of each sub-brick with the median sub-brick (default\
            method).
        quadrant: Quality index is 1 minus the quadrant correlation coefficient\
            as the quality index.
        autoclip: Clip off low-intensity regions in the median sub-brick, only\
            compute correlation between high-intensity voxels.
        automask: Automatically mask and compute correlation only across\
            high-intensity (presumably brain) voxels.
        clip: Clip off values below given threshold in the median sub-brick.
        mask: Compute correlation only across masked voxels from the given\
            dataset.
        range_: Print the median-3.5*MAD and median+3.5*MAD values with each\
            quality index for plotting.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTqualOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TQUAL_METADATA)
    cargs = []
    cargs.append("3dTqual")
    cargs.append(execution.input_file(dataset))
    if spearman:
        cargs.append("-spearman")
    if quadrant:
        cargs.append("-quadrant")
    if autoclip:
        cargs.append("-autoclip")
    if automask:
        cargs.append("-automask")
    if clip is not None:
        cargs.extend([
            "-clip",
            str(clip)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if range_:
        cargs.append("-range")
    ret = V3dTqualOutputs(
        root=execution.output_file("."),
        time_series=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTqualOutputs",
    "V_3D_TQUAL_METADATA",
    "v_3d_tqual",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_RETINO_PHASE_METADATA = Metadata(
    id="3db78d8b872cbcd25d2278819aa85d3e6ecbba57.boutiques",
    name="3dRetinoPhase",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dRetinoPhaseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_retino_phase(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    ecc_plus: OutputPathType
    """Output file for positive (expanding) eccentricity"""
    ecc_minus: OutputPathType
    """Output file for negative (contracting) eccentricity"""
    pol_plus: OutputPathType
    """Output file for clockwise polar angle mapping"""
    pol_minus: OutputPathType
    """Output file for counterclockwise polar angle mapping"""


def v_3d_retino_phase(
    prefix: str,
    dataset: InputPathType,
    exp: str | None = None,
    con: str | None = None,
    clw: str | None = None,
    ccw: str | None = None,
    spectra: bool = False,
    tstim: float | None = None,
    nrings: float | None = None,
    nwedges: float | None = None,
    ort_adjust: float | None = None,
    pre_stim: float | None = None,
    sum_adjust: str | None = None,
    phase_estimate: str | None = None,
    ref_ts: InputPathType | None = None,
    multi_ref_ts: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dRetinoPhaseOutputs:
    """
    Process time series from retinotopy stimuli to create phase datasets and visual
    field angle datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Prefix of output datasets.
        dataset: Time series from a retinotopy stimulus.
        exp: Expanding rings stimulus.
        con: Contracting rings stimulus.
        clw: Clockwise moving polar angle mapping stimulus.
        ccw: Counterclockwise moving polar angle mapping stimulus.
        spectra: Output amplitude and phase spectra datasets.
        tstim: Period of stimulus in seconds.
        nrings: Number of rings in the stimulus. Default is 1.
        nwedges: Number of wedges in the stimulus. Default is 1.
        ort_adjust: Number of DOF lost in detrending outside of this program.
        pre_stim: Blank period, in seconds, before stimulus began.
        sum_adjust: Adjust sum of angles for wrapping based on the angle\
            difference. Default is 'y'.
        phase_estimate: Method of phase estimation.
        ref_ts: 0 lag reference time series of response for DELAY phase\
            estimation method.
        multi_ref_ts: Multiple 0 lag reference time series. This allows you to\
            test multiple regressors.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dRetinoPhaseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_RETINO_PHASE_METADATA)
    cargs = []
    cargs.append("3dRetinoPhase")
    cargs.append(prefix)
    cargs.append(execution.input_file(dataset))
    if exp is not None:
        cargs.extend([
            "-exp",
            exp
        ])
    if con is not None:
        cargs.extend([
            "-con",
            con
        ])
    if clw is not None:
        cargs.extend([
            "-clw",
            clw
        ])
    if ccw is not None:
        cargs.extend([
            "-ccw",
            ccw
        ])
    if spectra:
        cargs.append("-spectra")
    if tstim is not None:
        cargs.extend([
            "-Tstim",
            str(tstim)
        ])
    if nrings is not None:
        cargs.extend([
            "-nrings",
            str(nrings)
        ])
    if nwedges is not None:
        cargs.extend([
            "-nwedges",
            str(nwedges)
        ])
    if ort_adjust is not None:
        cargs.extend([
            "-ort_adjust",
            str(ort_adjust)
        ])
    if pre_stim is not None:
        cargs.extend([
            "-pre_stim",
            str(pre_stim)
        ])
    if sum_adjust is not None:
        cargs.extend([
            "-sum_adjust",
            sum_adjust
        ])
    if phase_estimate is not None:
        cargs.extend([
            "-phase_estimate",
            phase_estimate
        ])
    if ref_ts is not None:
        cargs.extend([
            "-ref_ts",
            execution.input_file(ref_ts)
        ])
    if multi_ref_ts is not None:
        cargs.extend([
            "-multi_ref_ts",
            execution.input_file(multi_ref_ts)
        ])
    ret = V3dRetinoPhaseOutputs(
        root=execution.output_file("."),
        ecc_plus=execution.output_file(prefix + ".ecc+"),
        ecc_minus=execution.output_file(prefix + ".ecc-"),
        pol_plus=execution.output_file(prefix + ".pol+"),
        pol_minus=execution.output_file(prefix + ".pol-"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dRetinoPhaseOutputs",
    "V_3D_RETINO_PHASE_METADATA",
    "v_3d_retino_phase",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

COMPUTE_VOX2VOX_METADATA = Metadata(
    id="cac931a71ca00f1e6fd4a05be9aebaf5ca0482ec.boutiques",
    name="compute_vox2vox",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ComputeVox2voxOutputs(typing.NamedTuple):
    """
    Output object returned when calling `compute_vox2vox(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """The resulting transformed voxel-to-voxel 4dfp output file."""


def compute_vox2vox(
    source: InputPathType,
    t4file: InputPathType,
    target: InputPathType,
    runner: Runner | None = None,
) -> ComputeVox2voxOutputs:
    """
    Tool for computing voxel-to-voxel transformations.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        source: Input 4dfp source file.
        t4file: T4 transformation matrix file.
        target: Input 4dfp target file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ComputeVox2voxOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(COMPUTE_VOX2VOX_METADATA)
    cargs = []
    cargs.append("compute_vox2vox")
    cargs.append(execution.input_file(source))
    cargs.append(execution.input_file(t4file))
    cargs.append(execution.input_file(target))
    ret = ComputeVox2voxOutputs(
        root=execution.output_file("."),
        output=execution.output_file("<replace_with_output_path_pattern>"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "COMPUTE_VOX2VOX_METADATA",
    "ComputeVox2voxOutputs",
    "compute_vox2vox",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERT_TRANSFORM_FILE_METADATA = Metadata(
    id="224c137774aff43d94d1fecb5c8b4a19ae81816c.boutiques",
    name="ConvertTransformFile",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class ConvertTransformFileOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_transform_file(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def convert_transform_file(
    dimensions: int,
    input_transform_file: InputPathType,
    output_transform_file: str,
    runner: Runner | None = None,
) -> ConvertTransformFileOutputs:
    """
    Utility to read in a transform file (presumed to be in binary format) and output
    it in various formats. Default output is legacy human-readable text format.
    Without any options, the output filename extension must be .txt or .tfm to
    signify a text-formatted transform file.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dimensions: Dimensionality of the transform file.
        input_transform_file: Path to the input transform file.
        output_transform_file: Path for the output transform file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertTransformFileOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_TRANSFORM_FILE_METADATA)
    cargs = []
    cargs.append("ConvertTransformFile")
    cargs.append(str(dimensions))
    cargs.append(execution.input_file(input_transform_file))
    cargs.append(output_transform_file)
    cargs.append("[OPTIONS]")
    ret = ConvertTransformFileOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERT_TRANSFORM_FILE_METADATA",
    "ConvertTransformFileOutputs",
    "convert_transform_file",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TRAIN_GCS_ATLAS_METADATA = Metadata(
    id="b051aeba32a674e07cb3e233df372583e269e4c4.boutiques",
    name="train-gcs-atlas",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TrainGcsAtlasOutputs(typing.NamedTuple):
    """
    Output object returned when calling `train_gcs_atlas(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_gcs_file: OutputPathType
    """Output GCS file produced by training"""


def train_gcs_atlas(
    output_gcs: InputPathType,
    manual_parcellation: str | None = None,
    subjlist_file: InputPathType | None = None,
    hemi_spec: str | None = None,
    surf_reg: InputPathType | None = None,
    color_table: InputPathType | None = None,
    exclude_subject: str | None = None,
    jackknife_flag: bool = False,
    aseg_filename: str | None = None,
    threads: float | None = None,
    runner: Runner | None = None,
) -> TrainGcsAtlasOutputs:
    """
    Script to train a surface-based gaussian classifier for cortical surface
    parcellation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        output_gcs: Output GCS file.
        manual_parcellation: Manual parcellation; default is aparc_edited.
        subjlist_file: File containing the list of subjects.
        hemi_spec: Specify hemisphere for processing.
        surf_reg: Surface registration file; default is sphere.reg.
        color_table: Color table file.
        exclude_subject: Exclude a subject from the atlas.
        jackknife_flag: Submit a job for each subject excluding it.
        aseg_filename: Aseg filename; default is aseg.auto.mgz.
        threads: Number of threads to use.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TrainGcsAtlasOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TRAIN_GCS_ATLAS_METADATA)
    cargs = []
    cargs.append("train-gcs-atlas")
    if manual_parcellation is not None:
        cargs.extend([
            "--man",
            manual_parcellation
        ])
    if subjlist_file is not None:
        cargs.extend([
            "--f",
            execution.input_file(subjlist_file)
        ])
    if hemi_spec is not None:
        cargs.extend([
            "--hemi",
            hemi_spec
        ])
    cargs.extend([
        "--o",
        execution.input_file(output_gcs)
    ])
    if surf_reg is not None:
        cargs.extend([
            "--reg",
            execution.input_file(surf_reg)
        ])
    if color_table is not None:
        cargs.extend([
            "--ctab",
            execution.input_file(color_table)
        ])
    if exclude_subject is not None:
        cargs.extend([
            "--x",
            exclude_subject
        ])
    if jackknife_flag:
        cargs.append("--jackknife")
    if aseg_filename is not None:
        cargs.extend([
            "--aseg",
            aseg_filename
        ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    ret = TrainGcsAtlasOutputs(
        root=execution.output_file("."),
        output_gcs_file=execution.output_file(pathlib.Path(output_gcs).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TRAIN_GCS_ATLAS_METADATA",
    "TrainGcsAtlasOutputs",
    "train_gcs_atlas",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NIFTI_INFORMATION_METADATA = Metadata(
    id="aae86bd1571798a6e19c7191f8f0421755a39411.boutiques",
    name="nifti-information",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class NiftiInformationPrintHeader:
    """
    display the header contents.
    """
    opt_allow_truncated: bool = False
    """print the header even if the data is truncated"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-print-header")
        if self.opt_allow_truncated:
            cargs.append("-allow-truncated")
        return cargs


@dataclasses.dataclass
class NiftiInformationPrintXml:
    """
    print the cifti XML (cifti only).
    """
    opt_version_version: str | None = None
    """convert the XML to a specific CIFTI version (default is the file's cifti
    version): the CIFTI version to use"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-print-xml")
        if self.opt_version_version is not None:
            cargs.extend([
                "-version",
                self.opt_version_version
            ])
        return cargs


class NiftiInformationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `nifti_information(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def nifti_information(
    nifti_file: str,
    print_header: NiftiInformationPrintHeader | None = None,
    opt_print_matrix: bool = False,
    print_xml: NiftiInformationPrintXml | None = None,
    runner: Runner | None = None,
) -> NiftiInformationOutputs:
    """
    Display information about a nifti/cifti file.
    
    You must specify at least one -print-* option.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        nifti_file: the nifti/cifti file to examine.
        print_header: display the header contents.
        opt_print_matrix: output the values in the matrix (cifti only).
        print_xml: print the cifti XML (cifti only).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NiftiInformationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NIFTI_INFORMATION_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-nifti-information")
    cargs.append(nifti_file)
    if print_header is not None:
        cargs.extend(print_header.run(execution))
    if opt_print_matrix:
        cargs.append("-print-matrix")
    if print_xml is not None:
        cargs.extend(print_xml.run(execution))
    ret = NiftiInformationOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NIFTI_INFORMATION_METADATA",
    "NiftiInformationOutputs",
    "NiftiInformationPrintHeader",
    "NiftiInformationPrintXml",
    "nifti_information",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL_SUBJECT_MIXED_METADATA = Metadata(
    id="c89d204a94ff9a438c87e6af7616b21249be8dd9.boutiques",
    name="label_subject_mixed",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LabelSubjectMixedOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label_subject_mixed(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_aseg: OutputPathType
    """Labeled segmentation output"""


def label_subject_mixed(
    brain_mask: InputPathType,
    norm_volume: InputPathType,
    transform: InputPathType,
    gca_file: InputPathType,
    aseg_output: str,
    runner: Runner | None = None,
) -> LabelSubjectMixedOutputs:
    """
    Automatic labeling of brain regions using a Gaussian classifier array.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        brain_mask: Brain mask to be used for final labeling.
        norm_volume: Normalized volume.
        transform: Transform file in LTA format.
        gca_file: Gaussian classifier array (GCA) file.
        aseg_output: Output aseg file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelSubjectMixedOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_SUBJECT_MIXED_METADATA)
    cargs = []
    cargs.append("mri_ca_label")
    cargs.extend([
        "-mask",
        execution.input_file(brain_mask)
    ])
    cargs.append(execution.input_file(norm_volume))
    cargs.append(execution.input_file(transform))
    cargs.append(execution.input_file(gca_file))
    cargs.append(aseg_output)
    ret = LabelSubjectMixedOutputs(
        root=execution.output_file("."),
        output_aseg=execution.output_file(aseg_output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL_SUBJECT_MIXED_METADATA",
    "LabelSubjectMixedOutputs",
    "label_subject_mixed",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MC_METADATA = Metadata(
    id="60a4e6264f565573c6fbb9368b3b82aa19a0f230.boutiques",
    name="mri_mc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_mc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    extracted_surface: OutputPathType
    """The extracted surface output file."""


def mri_mc(
    input_volume: InputPathType,
    label_value: float,
    output_surface: str,
    connectivity: float | None = 1,
    runner: Runner | None = None,
) -> MriMcOutputs:
    """
    Extract a surface from a label volume using Marching Cubes algorithm.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: The input volume from which to extract the surface.
        label_value: The label value of the structure to extract.
        output_surface: The file where the extracted surface mesh will be\
            saved.
        connectivity: The connectivity used for Marching Cubes. Options are:\
            1=6+, 2=18, 3=6, 4=26.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MC_METADATA)
    cargs = []
    cargs.append("mri_mc")
    cargs.append(execution.input_file(input_volume))
    cargs.append(str(label_value))
    if connectivity is not None:
        cargs.append(output_surface + str(connectivity))
    ret = MriMcOutputs(
        root=execution.output_file("."),
        extracted_surface=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MC_METADATA",
    "MriMcOutputs",
    "mri_mc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_REGISTRATION_SY_N_SH_METADATA = Metadata(
    id="029fb8014cb72b8e3e10e60f5b05a9adf14dc918.boutiques",
    name="antsRegistrationSyN.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsRegistrationSyNShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_registration_sy_n_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    affine_transform: OutputPathType
    """Affine transformation matrix for registration"""
    inverse_warp: OutputPathType
    """Inverse warp field for registration"""
    forward_warp: OutputPathType
    """Forward warp field for registration"""


def ants_registration_sy_n_sh(
    image_dimension: typing.Literal[2, 3],
    fixed_image: InputPathType,
    moving_image: InputPathType,
    output_prefix: str,
    threads: int | None = None,
    initial_transform: list[str] | None = None,
    transform_type: typing.Literal["t", "r", "a", "s", "sr", "so", "b", "br", "bo"] | None = None,
    radius: int | None = None,
    spline_distance: int | None = None,
    gradient_step: float | None = None,
    masks: str | None = None,
    precision_type: typing.Literal["f", "d"] | None = None,
    use_histogram_matching: typing.Literal[0, 1] | None = None,
    use_repro_mode: typing.Literal[0, 1] | None = None,
    collapse_output_transforms: typing.Literal[0, 1] | None = None,
    random_seed: int | None = None,
    runner: Runner | None = None,
) -> AntsRegistrationSyNShOutputs:
    """
    Script for simplified symmetric image registration using ANTs.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Image dimension: 2 or 3 (for 2 or 3-dimensional\
            registration of a single volume).
        fixed_image: Fixed image(s) or source image(s) or reference image(s).
        moving_image: Moving image(s) or target image(s).
        output_prefix: A prefix that is prepended to all output files.
        threads: Number of threads (default =\
            ITK_GLOBAL_DEFAULT_NUMBER_OF_THREADS if defined, otherwise 1).
        initial_transform: Initial transform(s) --- order specified on the\
            command line matters.
        transform_type: Transform type (default = 's'). Options:\
            - t: translation (1 stage)\
            - r: rigid (1 stage)\
            - a: rigid + affine (2 stages)\
            - s: rigid + affine + deformable syn (3 stages)\
            - sr: rigid + deformable syn (2 stages)\
            - so: deformable syn only (1 stage)\
            - b: rigid + affine + deformable b-spline syn (3 stages)\
            - br: rigid + deformable b-spline syn (2 stages)\
            - bo: deformable b-spline syn only (1 stage).
        radius: Radius for cross correlation metric used during SyN stage\
            (default = 4).
        spline_distance: Spline distance for deformable B-spline SyN transform\
            (default = 26).
        gradient_step: Gradient step size for SyN and B-spline SyN (default =\
            0.1).
        masks: Mask(s) for the fixed image space, or for the fixed and moving\
            image space in the format 'fixedMask,MovingMask'. Use -x once to\
            specify mask(s) to be used for all stages or use -x for each 'stage'\
            (cf -t option). If no mask is to be used for a particular stage, the\
            keyword 'NULL' should be used in place of file names.
        precision_type: Precision type (default = 'd'). Options:\
            - f: float\
            - d: double.
        use_histogram_matching: Use histogram matching (default = 0). Options:\
            - 0: false\
            - 1: true.
        use_repro_mode: Use 'repro' mode for exact reproducibility of output.\
            Uses GC metric for linear stages and a fixed random seed (default = 0).\
            Options:\
            - 0: false\
            - 1: true.
        collapse_output_transforms: Collapse output transforms (default = 1).\
            Options:\
            - 0: false\
            - 1: true.
        random_seed: Fix random seed to an int value.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsRegistrationSyNShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_REGISTRATION_SY_N_SH_METADATA)
    cargs = []
    cargs.append("antsRegistrationSyN.sh")
    cargs.extend([
        "-d",
        str(image_dimension)
    ])
    cargs.extend([
        "-f",
        execution.input_file(fixed_image)
    ])
    cargs.extend([
        "-m",
        execution.input_file(moving_image)
    ])
    cargs.extend([
        "-o",
        output_prefix
    ])
    if threads is not None:
        cargs.extend([
            "-n",
            str(threads)
        ])
    if initial_transform is not None:
        cargs.extend([
            "-i",
            "[" + ",".join(initial_transform) + "]"
        ])
    if transform_type is not None:
        cargs.extend([
            "-t",
            transform_type
        ])
    if radius is not None:
        cargs.extend([
            "-r",
            str(radius)
        ])
    if spline_distance is not None:
        cargs.extend([
            "-s",
            str(spline_distance)
        ])
    if gradient_step is not None:
        cargs.extend([
            "-g",
            str(gradient_step)
        ])
    if masks is not None:
        cargs.extend([
            "-x",
            masks
        ])
    if precision_type is not None:
        cargs.extend([
            "-p",
            precision_type
        ])
    if use_histogram_matching is not None:
        cargs.extend([
            "-j",
            str(use_histogram_matching)
        ])
    if use_repro_mode is not None:
        cargs.extend([
            "-y",
            str(use_repro_mode)
        ])
    if collapse_output_transforms is not None:
        cargs.extend([
            "-z",
            str(collapse_output_transforms)
        ])
    if random_seed is not None:
        cargs.extend([
            "-e",
            str(random_seed)
        ])
    ret = AntsRegistrationSyNShOutputs(
        root=execution.output_file("."),
        affine_transform=execution.output_file(output_prefix + "0GenericAffine.mat"),
        inverse_warp=execution.output_file(output_prefix + "1InverseWarp.nii.gz"),
        forward_warp=execution.output_file(output_prefix + "1Warp.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_REGISTRATION_SY_N_SH_METADATA",
    "AntsRegistrationSyNShOutputs",
    "ants_registration_sy_n_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_FIT_BIAS_METADATA = Metadata(
    id="5cfc424aa0f54308ca89e9fae020adbc05a2f8ca.boutiques",
    name="mri_fit_bias",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriFitBiasOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_fit_bias(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_output: OutputPathType
    """Bias corrected output volume"""
    generated_bias_field: OutputPathType
    """Generated bias field"""


def mri_fit_bias(
    inputvol: InputPathType,
    segvol: InputPathType,
    maskvol: InputPathType,
    outvol: str,
    biasfield: str,
    lpf_cutoff: float | None = 23.0,
    dctvol: str | None = None,
    threshold: float | None = None,
    nerode: float | None = 1,
    nthreads: float | None = None,
    debug: bool = False,
    checkopts: bool = False,
    runner: Runner | None = None,
) -> MriFitBiasOutputs:
    """
    A tool for intensity normalization and bias correction in MRI images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        inputvol: Input volume for intensity normalization.
        segvol: Segmentation volume to define WM and Cortex (e.g.,\
            aseg.presurf.mgz).
        maskvol: Mask volume; zero everything outside of the mask (e.g.,\
            brainmask.mgz).
        outvol: Bias corrected output volume.
        biasfield: Output bias field.
        lpf_cutoff: Low-pass filter cutoff in mm (default is 23.000000).
        dctvol: DCT fields file for debugging.
        threshold: Mask out anything <= threshold value.
        nerode: 3D erode segmentation by n steps (default is 1).
        nthreads: Number of threads to use.
        debug: Turn on debugging mode.
        checkopts: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriFitBiasOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_FIT_BIAS_METADATA)
    cargs = []
    cargs.append("mri_fit_bias")
    cargs.extend([
        "--i",
        execution.input_file(inputvol)
    ])
    if lpf_cutoff is not None:
        cargs.extend([
            "--cutoff",
            str(lpf_cutoff)
        ])
    cargs.extend([
        "--seg",
        execution.input_file(segvol)
    ])
    cargs.extend([
        "--mask",
        execution.input_file(maskvol)
    ])
    cargs.extend([
        "--o",
        outvol
    ])
    cargs.extend([
        "--bias",
        biasfield
    ])
    if dctvol is not None:
        cargs.extend([
            "--dct",
            dctvol
        ])
    if threshold is not None:
        cargs.extend([
            "--thresh",
            str(threshold)
        ])
    if nerode is not None:
        cargs.extend([
            "--erode",
            str(nerode)
        ])
    if nthreads is not None:
        cargs.extend([
            "--threads",
            str(nthreads)
        ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    ret = MriFitBiasOutputs(
        root=execution.output_file("."),
        corrected_output=execution.output_file(outvol),
        generated_bias_field=execution.output_file(biasfield),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_FIT_BIAS_METADATA",
    "MriFitBiasOutputs",
    "mri_fit_bias",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MKIMA_INDEX_TCL_METADATA = Metadata(
    id="c105809b402206036812e673c076cf9989e47ed5.boutiques",
    name="mkima_index.tcl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MkimaIndexTclOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mkima_index_tcl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file resulting from mkima index operations."""


def mkima_index_tcl(
    input_file: InputPathType,
    output_flag: bool = False,
    runner: Runner | None = None,
) -> MkimaIndexTclOutputs:
    """
    A command-line tool for handling mkima index operations.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input file for mkima index operations.
        output_flag: Flag to specify output for mkima index operation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MkimaIndexTclOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MKIMA_INDEX_TCL_METADATA)
    cargs = []
    cargs.append("mkima_index.tcl")
    cargs.append(execution.input_file(input_file))
    if output_flag:
        cargs.append("-o")
    ret = MkimaIndexTclOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(input_file).name + "_index_output"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MKIMA_INDEX_TCL_METADATA",
    "MkimaIndexTclOutputs",
    "mkima_index_tcl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_GTMSEG_METADATA = Metadata(
    id="2c164b92c884894655aa369148327d84b308bec1.boutiques",
    name="mri_gtmseg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriGtmsegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_gtmseg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_gtmseg(
    output_volume: str,
    source_subject: str,
    internal_usf: float | None = None,
    apas_file: InputPathType | None = None,
    context_annotation: list[str] | None = None,
    subseg_wm: bool = False,
    wm_annotation: list[str] | None = None,
    dmax: float | None = None,
    keep_hypo: bool = False,
    keep_cc: bool = False,
    ctab: InputPathType | None = None,
    lhminmax: list[float] | None = None,
    rhminmax: list[float] | None = None,
    output_usf: float | None = None,
    threads: float | None = None,
    threads_max: bool = False,
    threads_max_1: bool = False,
    debug: bool = False,
    check_opts: bool = False,
    runner: Runner | None = None,
) -> MriGtmsegOutputs:
    """
    Creates a segmentation that can be used with the geometric transfer matrix
    (GTM).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        output_volume: Output volume (output will be subject/mri/outvol).
        source_subject: Source subject.
        internal_usf: Upsampling factor (default 2).
        apas_file: Defines extra-cerebral and subcortical segmentations\
            (apas+head.mgz).
        context_annotation: Use annotation to segment cortex\
            (aparc.annot,1000,2000).
        subseg_wm: Turn on segmenting of WM into smaller parts (off by default).
        wm_annotation: Use annotation to subsegment white matter.
        dmax: Distance from cortex for white matter segmentation to be\
            considered 'unsegmented' (default 5.000000).
        keep_hypo: Do not convert white matter hypointensities to a white\
            matter label.
        keep_cc: Do not convert corpus callosum to a white matter label.
        ctab: Copy items in ctab.lut into master ctab merging or overwriting\
            what is there.
        lhminmax: For defining left hemisphere ribbon in APAS (default: 1000\
            1900).
        rhminmax: For defining right hemisphere ribbon in APAS (default: 2000\
            2900).
        output_usf: Set actual output resolution. Default is to be the same as\
            the --internal-usf.
        threads: Use N threads (with Open MP).
        threads_max: Use the maximum allowable number of threads for this\
            computer.
        threads_max_1: Use one less than the maximum allowable number of\
            threads for this computer.
        debug: Turn on debugging.
        check_opts: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriGtmsegOutputs`).
    """
    if context_annotation is not None and (len(context_annotation) != 3): 
        raise ValueError(f"Length of 'context_annotation' must be 3 but was {len(context_annotation)}")
    if wm_annotation is not None and (len(wm_annotation) != 3): 
        raise ValueError(f"Length of 'wm_annotation' must be 3 but was {len(wm_annotation)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_GTMSEG_METADATA)
    cargs = []
    cargs.append("mri_gtmseg")
    cargs.extend([
        "--o",
        output_volume
    ])
    cargs.extend([
        "--s",
        source_subject
    ])
    if internal_usf is not None:
        cargs.extend([
            "--internal-usf",
            str(internal_usf)
        ])
    if apas_file is not None:
        cargs.extend([
            "--apas",
            execution.input_file(apas_file)
        ])
    if context_annotation is not None:
        cargs.extend([
            "--ctx-annot",
            *context_annotation
        ])
    if subseg_wm:
        cargs.append("--subseg-wm")
    if wm_annotation is not None:
        cargs.extend([
            "--wm-annot",
            *wm_annotation
        ])
    if dmax is not None:
        cargs.extend([
            "--dmax",
            str(dmax)
        ])
    if keep_hypo:
        cargs.append("--keep-hypo")
    if keep_cc:
        cargs.append("--keep-cc")
    if ctab is not None:
        cargs.extend([
            "--ctab",
            execution.input_file(ctab)
        ])
    if lhminmax is not None:
        cargs.extend([
            "--lhminmax",
            *map(str, lhminmax)
        ])
    if rhminmax is not None:
        cargs.extend([
            "--rhminmax",
            *map(str, rhminmax)
        ])
    if output_usf is not None:
        cargs.extend([
            "--output-usf",
            str(output_usf)
        ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if threads_max:
        cargs.append("--threads-max")
    if threads_max_1:
        cargs.append("--threads-max-1")
    if debug:
        cargs.append("--debug")
    if check_opts:
        cargs.append("--checkopts")
    ret = MriGtmsegOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_GTMSEG_METADATA",
    "MriGtmsegOutputs",
    "mri_gtmseg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_POLV_METADATA = Metadata(
    id="ee8644189f031978bc3740be0222cfee554fee9b.boutiques",
    name="mri_polv",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriPolvOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_polv(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_polv(
    input_image: InputPathType,
    output_image: InputPathType,
    window_size: float | None = None,
    runner: Runner | None = None,
) -> MriPolvOutputs:
    """
    Calculate an image specifying the plane of least variance at each point in the
    input image.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_image: The input image file for processing.
        output_image: The output image file specifying the plane of least\
            variance.
        window_size: Specify the window size to be used in the calculation of\
            the central plane of least variance (default=5).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriPolvOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_POLV_METADATA)
    cargs = []
    cargs.append("mri_polv")
    if window_size is not None:
        cargs.extend([
            "-w",
            str(window_size)
        ])
    cargs.append(execution.input_file(input_image))
    cargs.append(execution.input_file(output_image))
    ret = MriPolvOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_POLV_METADATA",
    "MriPolvOutputs",
    "mri_polv",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EPI_B0_CORRECT_METADATA = Metadata(
    id="690e7b1a6986e67ced0f065ca6d025cd2006e8eb.boutiques",
    name="epi_b0_correct",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class EpiB0CorrectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `epi_b0_correct(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    warp_dset: OutputPathType
    """Warp dataset containing the warp along the phase encode axis."""
    cmds_script: OutputPathType
    """Script of the commands used to generate the warp and process the EPI."""
    params_txt: OutputPathType
    """Text file of parameters input or derived from datasets."""
    unwarped_epi: OutputPathType
    """EPI dataset with estimated distortion correction applied."""
    qc_image_dir: OutputPathType
    """Directory containing QC images."""


def epi_b0_correct(
    prefix: str,
    input_freq: InputPathType,
    input_epi: InputPathType,
    epi_pe_dir: str,
    input_mask: InputPathType | None = None,
    input_magn: InputPathType | None = None,
    input_anat: InputPathType | None = None,
    input_json: InputPathType | None = None,
    epi_pe_bwpp: float | None = None,
    epi_pe_echo_sp: float | None = None,
    epi_pe_vox_dim: float | None = None,
    scale_freq: float | None = None,
    out_cmds: str | None = None,
    out_pars: str | None = None,
    wdir_name: str | None = None,
    blur_sigma: float | None = None,
    do_recenter_freq: str | None = None,
    mask_dilate: list[float] | None = None,
    no_clean: bool = False,
    qc_box_focus_ulay: bool = False,
    no_qc_image: bool = False,
    help_: bool = False,
    ver: bool = False,
    date: bool = False,
    runner: Runner | None = None,
) -> EpiB0CorrectOutputs:
    """
    B0 distortion correction tool using an acquired frequency (phase) image.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Prefix of output files; can include path.
        input_freq: Phase dataset (frequency volume); should be at similar\
            resolution and FOV as the EPI dataset; must be scaled appropriately.
        input_epi: EPI dataset to which B0 distortion correction will be\
            applied.
        epi_pe_dir: Direction (axis) of phase encoding, e.g., AP, PA, RL, ...
        input_mask: Mask of brain volume.
        input_magn: Magnitude dataset from which to estimate brain mask; can be\
            used for QC imaging.
        input_anat: Anatomical dataset to be used as underlay for QC images\
            (optional).
        input_json: JSON file containing parameters about the EPI dataset.
        epi_pe_bwpp: Bandwidth per pixel (in Hz) in the EPI dataset along the\
            phase encode direction.
        epi_pe_echo_sp: Effective TE spacing of the phase encoded volume, in\
            seconds.
        epi_pe_vox_dim: Voxel size along the EPI dataset's phase encode axis,\
            in mm.
        scale_freq: Scale to apply to frequency volume to match units (def:\
            SF=1.0).
        out_cmds: Name for output script recording commands (def:\
            PREFIX_cmds.tcsh).
        out_pars: Name for output text file recording relevant parameters (def:\
            PREFIX_pars.txt).
        wdir_name: Working directory name (def: automatic name).
        blur_sigma: Amount of blurring to apply to masked phase encode dataset\
            (def: BS=9).
        do_recenter_freq: Method to recenter the phase volume within the brain\
            mask (def: MC=mode).
        mask_dilate: Erosion and dilation parameters for automask (when using\
            magnitude image).
        no_clean: Don't remove the temporary directory of intermediate files.
        qc_box_focus_ulay: Focus the QC images on an automask region of the\
            underlay dataset.
        no_qc_image: Don't generate QC images.
        help_: Display program help in terminal.
        ver: Display program version number in terminal.
        date: Display date of program's last update in terminal.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EpiB0CorrectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EPI_B0_CORRECT_METADATA)
    cargs = []
    cargs.append("epi_b0_correct.py")
    cargs.append(prefix)
    cargs.extend([
        "-in_freq",
        execution.input_file(input_freq)
    ])
    cargs.extend([
        "-in_epi",
        execution.input_file(input_epi)
    ])
    if input_mask is not None:
        cargs.extend([
            "-in_mask",
            execution.input_file(input_mask)
        ])
    if input_magn is not None:
        cargs.extend([
            "-in_magn",
            execution.input_file(input_magn)
        ])
    if input_anat is not None:
        cargs.extend([
            "-in_anat",
            execution.input_file(input_anat)
        ])
    if input_json is not None:
        cargs.extend([
            "-in_epi_json",
            execution.input_file(input_json)
        ])
    cargs.extend([
        "-epi_pe_dir",
        epi_pe_dir
    ])
    if epi_pe_bwpp is not None:
        cargs.extend([
            "-epi_pe_bwpp",
            str(epi_pe_bwpp)
        ])
    if epi_pe_echo_sp is not None:
        cargs.extend([
            "-epi_pe_echo_sp",
            str(epi_pe_echo_sp)
        ])
    if epi_pe_vox_dim is not None:
        cargs.extend([
            "-epi_pe_voxdim",
            str(epi_pe_vox_dim)
        ])
    if scale_freq is not None:
        cargs.extend([
            "-scale_freq",
            str(scale_freq)
        ])
    if out_cmds is not None:
        cargs.extend([
            "-out_cmds",
            out_cmds
        ])
    if out_pars is not None:
        cargs.extend([
            "-out_pars",
            out_pars
        ])
    if wdir_name is not None:
        cargs.extend([
            "-wdir_name",
            wdir_name
        ])
    if blur_sigma is not None:
        cargs.extend([
            "-blur_sigma",
            str(blur_sigma)
        ])
    if do_recenter_freq is not None:
        cargs.extend([
            "-do_recenter_freq",
            do_recenter_freq
        ])
    if mask_dilate is not None:
        cargs.extend([
            "-mask_dilate",
            *map(str, mask_dilate)
        ])
    if no_clean:
        cargs.append("-no_clean")
    if qc_box_focus_ulay:
        cargs.append("-qc_box_focus_ulay")
    if no_qc_image:
        cargs.append("-no_qc_image")
    if help_:
        cargs.append("-help")
    if ver:
        cargs.append("-ver")
    if date:
        cargs.append("-date")
    ret = EpiB0CorrectOutputs(
        root=execution.output_file("."),
        warp_dset=execution.output_file(prefix + "_WARP.nii.gz"),
        cmds_script=execution.output_file(prefix + "_cmds.tcsh"),
        params_txt=execution.output_file(prefix + "_pars.txt"),
        unwarped_epi=execution.output_file(prefix + "_unwarped.nii.gz"),
        qc_image_dir=execution.output_file(prefix + "_QC/"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EPI_B0_CORRECT_METADATA",
    "EpiB0CorrectOutputs",
    "epi_b0_correct",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLSWAPDIM_FSL_METADATA = Metadata(
    id="7302b08bc4d86f9914f7a8203cbaf36cc9515b0c.boutiques",
    name="fslswapdim.fsl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FslswapdimFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslswapdim_fsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType | None
    """Output image with swapped dimensions"""


def fslswapdim_fsl(
    input_file: InputPathType,
    axis_a: str,
    axis_b: str,
    axis_c: str,
    output_file: str | None = None,
    runner: Runner | None = None,
) -> FslswapdimFslOutputs:
    """
    FSLSwapdim allows swapping and flipping of dimensions of an image.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input image file.
        axis_a: New X-axis in terms of the old axes; can be one of -x, x, y,\
            -y, z, -z or RL, LR, AP, PA, SI, IS.
        axis_b: New Y-axis in terms of the old axes; can be one of -x, x, y,\
            -y, z, -z or RL, LR, AP, PA, SI, IS.
        axis_c: New Z-axis in terms of the old axes; can be one of -x, x, y,\
            -y, z, -z or RL, LR, AP, PA, SI, IS.
        output_file: Output image file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslswapdimFslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLSWAPDIM_FSL_METADATA)
    cargs = []
    cargs.append("fslswapdim")
    cargs.append(execution.input_file(input_file))
    cargs.append(axis_a)
    cargs.append(axis_b)
    cargs.append(axis_c)
    if output_file is not None:
        cargs.append(output_file)
    ret = FslswapdimFslOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(output_file) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLSWAPDIM_FSL_METADATA",
    "FslswapdimFslOutputs",
    "fslswapdim_fsl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_2DCAT_METADATA = Metadata(
    id="86c841e523ad32a9e63fcb9b28fa7555580ced48.boutiques",
    name="2dcat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V2dcatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_2dcat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType | None
    """The main output image matrix file."""
    output_1_d: OutputPathType | None
    """A 1D file containing the average of RGB values, if the prefix ends with
    .1D."""


def v_2dcat(
    filenames: list[InputPathType],
    scale_image: InputPathType | None = None,
    scale_pixels: InputPathType | None = None,
    scale_intensity: bool = False,
    gscale: float | None = None,
    rgb_out: bool = False,
    res_in: list[float] | None = None,
    respad_in: list[float] | None = None,
    pad_val: float | None = None,
    crop: list[float] | None = None,
    autocrop_ctol: float | None = None,
    autocrop_atol: float | None = None,
    autocrop: bool = False,
    zero_wrap: bool = False,
    white_wrap: bool = False,
    gray_wrap: float | None = None,
    image_wrap: bool = False,
    rand_wrap: bool = False,
    prefix: str | None = None,
    matrix: list[float] | None = None,
    nx: float | None = None,
    ny: float | None = None,
    matrix_from_scale: bool = False,
    gap: float | None = None,
    gap_col: list[float] | None = None,
    runner: Runner | None = None,
) -> V2dcatOutputs:
    """
    Puts a set of images into an image matrix montage of NX by NY images.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        filenames: List of input image files.
        scale_image: Multiply each image in the output image matrix by the\
            color or intensity of the pixel in the scale image.
        scale_pixels: Multiply each pixel in the output image by the color or\
            intensity of the pixel in the scale image. The scale image is resized\
            to the output image's resolution.
        scale_intensity: Use the intensity (average color) of the pixel instead\
            of its color.
        gscale: Apply additional scaling factor.
        rgb_out: Force output to be in RGB, even if input is bytes.
        res_in: Set resolution of all input images.
        respad_in: Resample to max while respecting the aspect ratio, then pad\
            to desired pixel count.
        pad_val: Set the padding value when using -respad_in. Should be in the\
            range [0, 255], default is 0.
        crop: Crop images by specified number of pixels from the left, right,\
            top, and bottom.
        autocrop_ctol: Automatically crop lines where RGB values differ by less\
            than the specified percentage from the corner pixel values.
        autocrop_atol: Automatically crop lines where RGB values differ by less\
            than the specified percentage from the line average.
        autocrop: Automatically crop lines with default tolerances using both\
            autocrop_atol and autocrop_ctol set to 20.
        zero_wrap: Use solid black images if not enough images are provided to\
            fill the matrix.
        white_wrap: Use solid white images if not enough images are provided to\
            fill the matrix.
        gray_wrap: Use solid gray images if not enough images are provided to\
            fill the matrix. The gray value must be between 0 and 1.0.
        image_wrap: Reuse images to fill the matrix. This is the default\
            behavior.
        rand_wrap: Randomize the order of images when reusing to fill the\
            matrix.
        prefix: Prefix the output file names with the specified string.
        matrix: Specify the number of images in each row (NX) and column (NY)\
            of the image matrix.
        nx: Specify the number of images in each row.
        ny: Specify the number of images in each column.
        matrix_from_scale: Set matrix dimensions NX and NY to be the same as\
            the SCALE_IMG's dimensions. Requires the -scale_image option.
        gap: Put a gap of specified pixels between images.
        gap_col: Set color of the gap line to specified R, G, B values. Values\
            range from 0 to 255.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V2dcatOutputs`).
    """
    if pad_val is not None and not (0 <= pad_val <= 255): 
        raise ValueError(f"'pad_val' must be between 0 <= x <= 255 but was {pad_val}")
    if gray_wrap is not None and not (0 <= gray_wrap <= 1): 
        raise ValueError(f"'gray_wrap' must be between 0 <= x <= 1 but was {gray_wrap}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_2DCAT_METADATA)
    cargs = []
    cargs.append("2dcat")
    cargs.extend([execution.input_file(f) for f in filenames])
    if scale_image is not None:
        cargs.extend([
            "-scale_image",
            execution.input_file(scale_image)
        ])
    if scale_pixels is not None:
        cargs.extend([
            "-scale_pixels",
            execution.input_file(scale_pixels)
        ])
    if scale_intensity:
        cargs.append("-scale_intensity")
    if gscale is not None:
        cargs.extend([
            "-gscale",
            str(gscale)
        ])
    if rgb_out:
        cargs.append("-rgb_out")
    if res_in is not None:
        cargs.extend([
            "-res_in",
            *map(str, res_in)
        ])
    if respad_in is not None:
        cargs.extend([
            "-respad_in",
            *map(str, respad_in)
        ])
    if pad_val is not None:
        cargs.extend([
            "-pad_val",
            str(pad_val)
        ])
    if crop is not None:
        cargs.extend([
            "-crop",
            *map(str, crop)
        ])
    if autocrop_ctol is not None:
        cargs.extend([
            "-autocrop_ctol",
            str(autocrop_ctol)
        ])
    if autocrop_atol is not None:
        cargs.extend([
            "-autocrop_atol",
            str(autocrop_atol)
        ])
    if autocrop:
        cargs.append("-autocrop")
    if zero_wrap:
        cargs.append("-zero_wrap")
    if white_wrap:
        cargs.append("-white_wrap")
    if gray_wrap is not None:
        cargs.extend([
            "-gray_wrap",
            str(gray_wrap)
        ])
    if image_wrap:
        cargs.append("-image_wrap")
    if rand_wrap:
        cargs.append("-rand_wrap")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if matrix is not None:
        cargs.extend([
            "-matrix",
            *map(str, matrix)
        ])
    if nx is not None:
        cargs.extend([
            "-nx",
            str(nx)
        ])
    if ny is not None:
        cargs.extend([
            "-ny",
            str(ny)
        ])
    if matrix_from_scale:
        cargs.append("-matrix_from_scale")
    if gap is not None:
        cargs.extend([
            "-gap",
            str(gap)
        ])
    if gap_col is not None:
        cargs.extend([
            "-gap_col",
            *map(str, gap_col)
        ])
    ret = V2dcatOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(prefix + ".ppm") if (prefix is not None) else None,
        output_1_d=execution.output_file(prefix + ".1D") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V2dcatOutputs",
    "V_2DCAT_METADATA",
    "v_2dcat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_WEIGHTED_STATS_METADATA = Metadata(
    id="da2eeba1fe23ffefb27247087cb14abe89c34b0c.boutiques",
    name="volume-weighted-stats",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class VolumeWeightedStatsWeightVolume:
    """
    use weights from a volume file.
    """
    weight_volume: InputPathType
    """volume file containing the weights"""
    opt_match_maps: bool = False
    """each subvolume of input uses the corresponding subvolume from the weights
    file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-weight-volume")
        cargs.append(execution.input_file(self.weight_volume))
        if self.opt_match_maps:
            cargs.append("-match-maps")
        return cargs


@dataclasses.dataclass
class VolumeWeightedStatsRoi:
    """
    only consider data inside an roi.
    """
    roi_volume: InputPathType
    """the roi, as a volume file"""
    opt_match_maps: bool = False
    """each subvolume of input uses the corresponding subvolume from the roi
    file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-roi")
        cargs.append(execution.input_file(self.roi_volume))
        if self.opt_match_maps:
            cargs.append("-match-maps")
        return cargs


@dataclasses.dataclass
class VolumeWeightedStatsStdev:
    """
    compute weighted standard deviation.
    """
    opt_sample: bool = False
    """estimate population stdev from the sample"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-stdev")
        if self.opt_sample:
            cargs.append("-sample")
        return cargs


class VolumeWeightedStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_weighted_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def volume_weighted_stats(
    volume_in: InputPathType,
    weight_volume: VolumeWeightedStatsWeightVolume | None = None,
    opt_subvolume_subvolume: str | None = None,
    roi: VolumeWeightedStatsRoi | None = None,
    opt_mean: bool = False,
    stdev: VolumeWeightedStatsStdev | None = None,
    opt_percentile_percent: float | None = None,
    opt_sum: bool = False,
    opt_show_map_name: bool = False,
    runner: Runner | None = None,
) -> VolumeWeightedStatsOutputs:
    """
    Weighted spatial statistics on a volume file.
    
    For each subvolume of the input, a line of text is printed, resulting from
    the specified operation. If -weight-volume is not specified, each voxel's
    volume is used. Use -subvolume to only give output for a single subvolume.
    If the -roi option is used without -match-maps, then each line will contain
    as many numbers as there are maps in the ROI file, separated by tab
    characters. Exactly one of -mean, -stdev, -percentile or -sum must be
    specified.
    
    Using -sum without -weight-volume is equivalent to integrating with respect
    to volume.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the input volume.
        weight_volume: use weights from a volume file.
        opt_subvolume_subvolume: only display output for one subvolume: the\
            subvolume number or name.
        roi: only consider data inside an roi.
        opt_mean: compute weighted mean.
        stdev: compute weighted standard deviation.
        opt_percentile_percent: compute weighted percentile: the percentile to\
            find, must be between 0 and 100.
        opt_sum: compute weighted sum.
        opt_show_map_name: print map index and name before each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeWeightedStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_WEIGHTED_STATS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-weighted-stats")
    cargs.append(execution.input_file(volume_in))
    if weight_volume is not None:
        cargs.extend(weight_volume.run(execution))
    if opt_subvolume_subvolume is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvolume
        ])
    if roi is not None:
        cargs.extend(roi.run(execution))
    if opt_mean:
        cargs.append("-mean")
    if stdev is not None:
        cargs.extend(stdev.run(execution))
    if opt_percentile_percent is not None:
        cargs.extend([
            "-percentile",
            str(opt_percentile_percent)
        ])
    if opt_sum:
        cargs.append("-sum")
    if opt_show_map_name:
        cargs.append("-show-map-name")
    ret = VolumeWeightedStatsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_WEIGHTED_STATS_METADATA",
    "VolumeWeightedStatsOutputs",
    "VolumeWeightedStatsRoi",
    "VolumeWeightedStatsStdev",
    "VolumeWeightedStatsWeightVolume",
    "volume_weighted_stats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_DWUNCERT_METADATA = Metadata(
    id="8f7f239d86c536d7e540a83e127aed316e05a15c.boutiques",
    name="3dDWUncert",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dDwuncertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_dwuncert(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """AFNI-format file with 6 subbricks, containing uncertainty information."""


def v_3d_dwuncert(
    input_file: InputPathType,
    input_prefix: str,
    output_prefix: str,
    grad_file: InputPathType | None = None,
    bmatrix_file: InputPathType | None = None,
    num_iters: float | None = None,
    mask_file: InputPathType | None = None,
    calc_thr_fa: float | None = None,
    csf_fa: float | None = None,
    runner: Runner | None = None,
) -> V3dDwuncertOutputs:
    """
    Use jackknifing to estimate uncertainty of DTI parameters, important for
    probabilistic tractography.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_file: Input file with b0 and DWI subbricks.
        input_prefix: Basename of DTI volumes.
        output_prefix: Output file name prefix.
        grad_file: File with 3 columns for x-, y-, and z-comps of DW-gradients.
        bmatrix_file: File with gradient info in b-matrix format.
        num_iters: Number of jackknife resample iterations.
        mask_file: Mask file within which to calculate uncertainty.
        calc_thr_fa: Threshold for the minimum FA value above which to\
            calculate uncertainty.
        csf_fa: Number marking FA value of 'bad' voxels.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dDwuncertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_DWUNCERT_METADATA)
    cargs = []
    cargs.append("3dDWUncert")
    cargs.extend([
        "-inset",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-input",
        input_prefix
    ])
    cargs.extend([
        "-prefix",
        output_prefix
    ])
    if grad_file is not None:
        cargs.extend([
            "-grads",
            execution.input_file(grad_file)
        ])
    if bmatrix_file is not None:
        cargs.extend([
            "-bmatrix_FULL",
            execution.input_file(bmatrix_file)
        ])
    if num_iters is not None:
        cargs.extend([
            "-iters",
            str(num_iters)
        ])
    if mask_file is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_file)
        ])
    if calc_thr_fa is not None:
        cargs.extend([
            "-calc_thr_FA",
            str(calc_thr_fa)
        ])
    if csf_fa is not None:
        cargs.extend([
            "-csf_fa",
            str(csf_fa)
        ])
    ret = V3dDwuncertOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_prefix + "+*.HEAD/" + output_prefix + "+*.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dDwuncertOutputs",
    "V_3D_DWUNCERT_METADATA",
    "v_3d_dwuncert",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DGEN_ARMA11_METADATA = Metadata(
    id="9fce1559df8cc31e0d2c99d44319f7a47b38ba76.boutiques",
    name="1dgenARMA11",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dgenArma11Outputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dgen_arma11(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """Generated ARMA(1,1) time series"""


def v_1dgen_arma11(
    length_alt: float | None = None,
    num_series: float | None = None,
    param_a: float | None = None,
    param_b: float | None = None,
    param_lam: float | None = None,
    std_dev: float | None = None,
    normalize: bool = False,
    seed: float | None = None,
    corcut: float | None = None,
    arma31: str | None = None,
    arma51: str | None = None,
    runner: Runner | None = None,
) -> V1dgenArma11Outputs:
    """
    Program to generate an ARMA(1,1) time series, for simulation studies. Results
    are written to stdout.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        length_alt: Specify the length of the time series vector to generate\
            (equivalent to -num option).
        num_series: The number of time series vectors to generate; defaults to\
            1 if not given.
        param_a: Specify ARMA(1,1) parameters 'a'.
        param_b: Specify ARMA(1,1) parameter 'b' directly.
        param_lam: Specify ARMA(1,1) parameter 'b' indirectly.
        std_dev: Set standard deviation of results [default=1].
        normalize: Normalize time series so sum of squares is 1.
        seed: Set random number seed.
        corcut: Specify a cutoff for the correlation coefficient r(k) of noise\
            samples at k units apart. Default is 0.00010.
        arma31: Specify parameters for a restricted ARMA(3,1) model: -arma31 a\
            r theta vrat.
        arma51: Specify parameters for a restricted ARMA(5,1) model: -arma51 a\
            r1 theta1 r2 theta2 vrat.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dgenArma11Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DGEN_ARMA11_METADATA)
    cargs = []
    cargs.append("1dgenARMA11")
    if length_alt is not None:
        cargs.extend([
            "-len",
            str(length_alt)
        ])
    if num_series is not None:
        cargs.extend([
            "-nvec",
            str(num_series)
        ])
    if param_a is not None:
        cargs.extend([
            "-a",
            str(param_a)
        ])
    if param_b is not None:
        cargs.extend([
            "-b",
            str(param_b)
        ])
    if param_lam is not None:
        cargs.extend([
            "-lam",
            str(param_lam)
        ])
    if std_dev is not None:
        cargs.extend([
            "-sig",
            str(std_dev)
        ])
    if normalize:
        cargs.append("-norm")
    if seed is not None:
        cargs.extend([
            "-seed",
            str(seed)
        ])
    if corcut is not None:
        cargs.extend([
            "-CORcut",
            str(corcut)
        ])
    if arma31 is not None:
        cargs.extend([
            "-arma31",
            arma31
        ])
    if arma51 is not None:
        cargs.extend([
            "-arma51",
            arma51
        ])
    ret = V1dgenArma11Outputs(
        root=execution.output_file("."),
        output=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dgenArma11Outputs",
    "V_1DGEN_ARMA11_METADATA",
    "v_1dgen_arma11",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DIFFUSION_UTILS_METADATA = Metadata(
    id="644c1194ddc618947bb21fc39f90ede191a80b94.boutiques",
    name="diffusionUtils",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DiffusionUtilsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `diffusion_utils(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def diffusion_utils(
    dummy_flag: bool = False,
    runner: Runner | None = None,
) -> DiffusionUtilsOutputs:
    """
    A utility related to diffusion data, potentially using the DIPY library.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        dummy_flag: Dummy input as no valid help information is provided due to\
            missing module.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DiffusionUtilsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DIFFUSION_UTILS_METADATA)
    cargs = []
    cargs.append("diffusionUtils")
    if dummy_flag:
        cargs.append("--dummy")
    ret = DiffusionUtilsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DIFFUSION_UTILS_METADATA",
    "DiffusionUtilsOutputs",
    "diffusion_utils",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MAKE_TEMPLATE_METADATA = Metadata(
    id="c9957f7fb67720d6d1343a3342eb0a6545f5cf7a.boutiques",
    name="mris_make_template",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMakeTemplateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_make_template(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_make_template(
    hemi: str,
    surface_name: str,
    subjects: list[str],
    output_name: str,
    addframe_parameters: list[str] | None = None,
    vector: bool = False,
    norot: bool = False,
    rot: bool = False,
    annot: bool = False,
    overlay_parameters: list[str] | None = None,
    overlay_dir: str | None = None,
    scale: float | None = None,
    surf_dir: str | None = None,
    smooth_iterations: float | None = None,
    subjects_dir: str | None = None,
    runner: Runner | None = None,
) -> MrisMakeTemplateOutputs:
    """
    This program will add a template into an average surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        hemi: Hemisphere (e.g., 'lh' or 'rh').
        surface_name: Surface name (e.g., 'white', 'pial').
        subjects: List of subjects to be averaged.
        output_name: Output name for the template.
        addframe_parameters: Add a frame with specific field and location in\
            atlas.
        vector: Print additional information for addframe.
        norot: Not aligning hemispheres before averaging (default).
        rot: Rough rigid alignment of hemispheres before averaging.
        annot: Zero medial wall.
        overlay_parameters: Read overlay from file, specify number of averages.
        overlay_dir: Use directory for overlay hemi.
        scale: Scale value for transformation.
        surf_dir: Use custom subdirectory instead of 'surf'.
        smooth_iterations: Number of iterations to smooth curvature.
        subjects_dir: Specify SUBJECTS_DIR.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMakeTemplateOutputs`).
    """
    if addframe_parameters is not None and (len(addframe_parameters) != 2): 
        raise ValueError(f"Length of 'addframe_parameters' must be 2 but was {len(addframe_parameters)}")
    if overlay_parameters is not None and (len(overlay_parameters) != 2): 
        raise ValueError(f"Length of 'overlay_parameters' must be 2 but was {len(overlay_parameters)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MAKE_TEMPLATE_METADATA)
    cargs = []
    cargs.append("mris_make_template")
    cargs.append(hemi)
    cargs.append(surface_name)
    cargs.extend(subjects)
    cargs.append(output_name)
    if addframe_parameters is not None:
        cargs.extend([
            "-addframe",
            *addframe_parameters
        ])
    if vector:
        cargs.append("-vector")
    if norot:
        cargs.append("-norot")
    if rot:
        cargs.append("-rot")
    if annot:
        cargs.append("-annot")
    if overlay_parameters is not None:
        cargs.extend([
            "-overlay",
            *overlay_parameters
        ])
    if overlay_dir is not None:
        cargs.extend([
            "-overlay-dir",
            overlay_dir
        ])
    if scale is not None:
        cargs.extend([
            "-s",
            str(scale)
        ])
    if surf_dir is not None:
        cargs.extend([
            "-surf_dir",
            surf_dir
        ])
    if smooth_iterations is not None:
        cargs.extend([
            "-a",
            str(smooth_iterations)
        ])
    if subjects_dir is not None:
        cargs.extend([
            "-sdir",
            subjects_dir
        ])
    ret = MrisMakeTemplateOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MAKE_TEMPLATE_METADATA",
    "MrisMakeTemplateOutputs",
    "mris_make_template",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DTTEST___METADATA = Metadata(
    id="9816ba0be883f397c48e16a5a699629ad3d438ae.boutiques",
    name="3dttest++",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dttestOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dttest__(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType | None
    """Main output dataset"""
    residuals: OutputPathType | None
    """Output residuals dataset"""


def v_3dttest__(
    set_a: list[str],
    set_b: list[str] | None = None,
    set_a_long: list[str] | None = None,
    set_b_long: list[str] | None = None,
    covariates: InputPathType | None = None,
    label_a: str | None = None,
    label_b: str | None = None,
    setweight_a: InputPathType | None = None,
    setweight_b: InputPathType | None = None,
    prefix: str | None = None,
    resid: str | None = None,
    paired: bool = False,
    unpooled: bool = False,
    mask: InputPathType | None = None,
    exblur: int | None = None,
    randomsign: bool = False,
    permute: bool = False,
    etac: bool = False,
    etac_blur: list[float] | None = None,
    etac_opt: list[str] | None = None,
    seed: float | None = None,
    runner: Runner | None = None,
) -> V3dttestOutputs:
    """
    Gosset (Student) t-test of sets of 3D datasets in AFNI.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        set_a: Set A in short form, e.g., 'a+tlrc[3]' b+tlrc[3] ...'.
        set_b: Set B in short form, e.g., 'x+tlrc[3]' y+tlrc[3] ...'.
        set_a_long: Specify an overall name for the set of datasets (Long\
            form). Example: -setA Green sub001 a+tlrc[3] sub002 b+tlrc[3] ...
        set_b_long: Specify an overall name for the set of datasets (Long\
            form). Example: -setB Blue sub001 x+tlrc[3] sub002 y+tlrc[3] ...
        covariates: File containing covariates.
        label_a: Label for the set (for Set A). Limited to 12 characters.
        label_b: Label for the set (for Set B). Limited to 12 characters.
        setweight_a: File with voxel-wise weights for -setA datasets.
        setweight_b: File with voxel-wise weights for -setB datasets.
        prefix: Output the prefix name of the dataset result. For surface-based\
            datasets, use -prefix p.niml.dset or -prefix p.gii.dset.
        resid: Residuals will be output into a dataset with the given prefix.
        paired: Specify to use a paired-sample t-test to compare setA and setB.\
            Both sets must have the same cardinality.
        unpooled: Specify separate variance estimates for setA and setB (not\
            pooled together).
        mask: Set mask for dataset analysis.
        exblur: Add extra Gaussian blurring kernel FWHM (mm). Example: -exblur\
            6.
        randomsign: Randomize signs of datasets. Used with output from -resid\
            to generate null hypothesis statistics.
        permute: With -randomsign, adds inter-set permutation to randomization\
            when both sets are used.
        etac: Apply the Equitable Thresholding And Clustering (ETAC) method for\
            thresholding results.
        etac_blur: List of multiple levels of spatial blurring for ETAC.\
            Example: -ETAC_blur 4 6.
        etac_opt: Specify options for ETAC. Example: -ETAC_opt\
            NN=2:sid=2:hpow=0,2:pthr=0.01,0.005,0.002,0.01:name=Fred.
        seed: Random number seed for -randomsign and -permute/ETAC.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dttestOutputs`).
    """
    if exblur is not None and not (0 <= exblur <= 100): 
        raise ValueError(f"'exblur' must be between 0 <= x <= 100 but was {exblur}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DTTEST___METADATA)
    cargs = []
    cargs.append("3dttest++")
    cargs.extend([
        "-setA",
        *set_a
    ])
    if set_b is not None:
        cargs.extend([
            "-setB",
            *set_b
        ])
    if set_a_long is not None:
        cargs.extend([
            "-setA",
            *set_a_long
        ])
    if set_b_long is not None:
        cargs.extend([
            "-setB",
            *set_b_long
        ])
    if covariates is not None:
        cargs.extend([
            "-covariates",
            execution.input_file(covariates)
        ])
    if label_a is not None:
        cargs.extend([
            "-labelA",
            label_a
        ])
    if label_b is not None:
        cargs.extend([
            "-labelB",
            label_b
        ])
    if setweight_a is not None:
        cargs.extend([
            "-setweightA",
            execution.input_file(setweight_a)
        ])
    if setweight_b is not None:
        cargs.extend([
            "-setweightB",
            execution.input_file(setweight_b)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if resid is not None:
        cargs.extend([
            "-resid",
            resid
        ])
    if paired:
        cargs.append("-paired")
    if unpooled:
        cargs.append("-unpooled")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if exblur is not None:
        cargs.extend([
            "-exblur",
            str(exblur)
        ])
    if randomsign:
        cargs.append("-randomsign")
    if permute:
        cargs.append("-permute")
    if etac:
        cargs.append("-ETAC")
    if etac_blur is not None:
        cargs.extend([
            "-ETAC_blur",
            *map(str, etac_blur)
        ])
    if etac_opt is not None:
        cargs.extend([
            "-ETAC_opt",
            *etac_opt
        ])
    if seed is not None:
        cargs.extend([
            "-seed",
            str(seed)
        ])
    ret = V3dttestOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(prefix + ".nii.gz") if (prefix is not None) else None,
        residuals=execution.output_file(resid + ".nii.gz") if (resid is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dttestOutputs",
    "V_3DTTEST___METADATA",
    "v_3dttest__",
]
